Tournament Portsmouth, England December 12th 1998 Rob Treasure https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/KvlduCXKobA/discussion Crypt (12 cards, min=10, max=35, avg=5.58) ------------------------------------------ 2x Lazverinus, Thrall of Lambach 10 AUS DOM FOR POT pro archbishop Ventrue antitribu:2 1x Ian Forestal 8 AUS DOM THA Tremere antitribu:2 1x Iliana 7 DOM FOR PRO tha Gangrel:2 1x Badger 6 FOR PRO ani pot Gangrel:1 1x Dylan 6 aus cel dom for pro Ventrue antitribu:2 1x Lisette Vizquel 6 DOM POT pro bishop Lasombra:2 1x Jimmy Dunn 4 CEL POT for Pander:2 1x Cameron 3 dom pot Lasombra:2 1x Juan Cali 3 aus for Ventrue antitribu:2 1x Ricki Van Demsi 3 for pro Gangrel:1 1x Uriah Winter 1 for pot Caitiff:1 Library (87 cards) Master (15) 1x Blood Doll 1x Cultivated Blood Shortage 1x Demonstration 1x Direct Intervention 1x Dominate 1x Dreams of the Sphinx 1x Fortitude 1x Giant's Blood 1x Humanitas 1x Information Highway 2x Minion Tap 1x Rack, The 1x Rumor Mill, Tabloid Newspaper, The 1x Sudden Reversal Action (10) 2x Ambush 1x Cull the Herd 4x Govern the Unaligned 3x Restoration Equipment (3) 1x Hand of Conrad 1x Ivory Bow 1x Signet of King Saul, The Retainer (2) 1x Homunculus 1x Mr. Winthrop Action Modifier (6) 2x Conditioning 2x Earth Control 1x Foreshadowing Destruction 1x Threats Action Modifier/Combat (2) 2x Rapid Change Reaction (16) 4x Deflection 2x Enhanced Senses 3x Forced Awakening 2x My Enemy's Enemy 2x Spirit's Touch 3x Wake with Evening's Freshness Combat (33) 3x Bone Spur 3x Disarm 1x Fists of Death 2x Flesh of Marble 3x Immortal Grapple 2x Indomitability 1x Pushing the Limit 2x Resilience 3x Rolling with the Punches 4x Skin of Steel 4x Taste of Vitae 2x Thrown Sewer Lid 1x Undead Strength 2x Unflinching Persistence